@@ -286,9 +286,6 @@ $lng['admin']['deactivated_user'] = 'Avaktivera användare';
 $lng['admin']['sendpassword'] = 'Skicka lösenord';
 $lng['admin']['ownvhostsettings'] = 'Egna vHost-Inställningar';
 $lng['admin']['configfiles']['serverconfiguration'] = 'Konfiguration';
-$lng['admin']['configfiles']['files'] = '<b>Konfigurationsfiler:</b> Ändra eller skapa följande filer med<br />följande innehåll om de inte finns redan.<br /><b>Notera:</b> MySQL-lösenordet har inte ändrats på grund av säkerhetsskäl.<br />Du måste själv ändra lösenordet &quot;MYSQL_PASSWORD&quot; på egen hand. Om du glömt bort ditt MySQL-password<br />så kan du hitta det här &quot;lib/userdata.inc.php&quot;.';
-$lng['admin']['configfiles']['commands'] = '<b>Kommandon:</b> Kör följande kommandon i ett terminalfönster.';
-$lng['admin']['configfiles']['restart'] = '<b>Omstart:</b> Kör följande kommandon i ett terminalfönster för att ladda in den nya konfigurationen.';
 $lng['admin']['templates']['templates'] = 'Mallar';
 $lng['admin']['templates']['template_add'] = '[Lägg till en ny mall]';
 $lng['admin']['templates']['template_edit'] = 'Ändra en befintlig mall';
