@@ -32,10 +32,12 @@ while ($maildir = $maildirs_stmt->fetch(PDO::FETCH_ASSOC)) {
 
 	$_maildir = makeCorrectDir($maildir['maildirpath']);
 
-	if (file_exists($_maildir) 
+	if (file_exists($_maildir)
 		&& is_dir($_maildir)
 	) {
-		$back = safe_exec('du -sk ' . escapeshellarg($_maildir) . '');
+		// mail-address allows many special characters, see http://en.wikipedia.org/wiki/Email_address#Local_part
+		$return = false;
+		$back = safe_exec('du -sk ' . escapeshellarg($_maildir), $return, array('|', '&', '`', '$', '~', '?'));
 		foreach ($back as $backrow) {
 			$emailusage = explode(' ', $backrow);
 		}
