@@ -299,6 +299,20 @@ class apache extends HttpConfigBase {
 						$this->virtualhosts_data[$vhosts_filename] .= '  Alias /fastcgiphp ' . $php->getInterface()->getAliasConfigDir() . $srvName . "\n";
 					}
 				}
+                else
+                {
+                    // mod_php
+                    $domain = array(
+                        'id' => 'none',
+                        'domain' => Settings::Get('system.hostname'),
+                        'adminid' => 1, /* first admin-user (superadmin) */
+                        'guid' => Settings::Get('system.httpuser'),
+                        'openbasedir' => 0,
+                        'email' => Settings::Get('panel.adminmail'),
+                        'loginname' => 'froxlor.panel',
+                        'documentroot' => $mypath
+                    );
+                }
 
 				/**
 				 * dirprotection, see #72
@@ -804,6 +818,13 @@ class apache extends HttpConfigBase {
 					$vhost_content .= '  SSLCertificateChainFile ' . makeCorrectFile($domain['ssl_cert_chainfile']) . "\n";
 				}
 			}
+			else
+			{
+			    // if there is no cert-file specified but we are generating a ssl-vhost,
+			    // we should return an empty string because this vhost would suck dick, ref #1583
+			    $this->logger->logAction(CRON_ACTION, LOG_ERROR, $domain['domain'] . ' :: empty certificate file! Cannot create ssl-directives');
+			    return '# no ssl-certificate was specified for this domain, therefore no explicit vhost is being generated';
+			}
 		}
 
 		if (preg_match('/^https?\:\/\//', $domain['documentroot'])) {
@@ -1046,7 +1067,7 @@ class apache extends HttpConfigBase {
 						if (!file_exists($perlsymlink)) {
 							safe_exec('ln -s '.escapeshellarg($suexecpath).' '.escapeshellarg($perlsymlink));
 						}
-						safe_exec('chown '.escapeshellarg($row_diroptions['guid']).':'.escapeshellarg($row_diroptions['guid']).' '.escapeshellarg($perlsymlink));
+						safe_exec('chown -h '.escapeshellarg($row_diroptions['guid']).':'.escapeshellarg($row_diroptions['guid']).' '.escapeshellarg($perlsymlink));
 					}
 				} else {
 					// if no perl-execution is enabled but the workaround is,
